@@ -10,9 +10,16 @@
 
 #include "elisa_settings.h"
 
+#include "playerLogging.h"
+
 #include <QTimer>
 #include <QDateTime>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#define PlaybackState State
+#define playbackState state
+#endif
+
 ManageAudioPlayer::ManageAudioPlayer(QObject *parent) : QObject(parent)
 {
 
@@ -52,7 +59,7 @@ QMediaPlayer::MediaStatus ManageAudioPlayer::playerStatus() const
     return mPlayerStatus;
 }
 
-QMediaPlayer::State ManageAudioPlayer::playerPlaybackState() const
+QMediaPlayer::PlaybackState ManageAudioPlayer::playerPlaybackState() const
 {
     return mPlayerPlaybackState;
 }
@@ -241,12 +248,10 @@ void ManageAudioPlayer::setPlayerStatus(QMediaPlayer::MediaStatus playerStatus)
     case QMediaPlayer::InvalidMedia:
         triggerSkipNextTrack();
         break;
-    case QMediaPlayer::UnknownMediaStatus:
-        break;
     }
 }
 
-void ManageAudioPlayer::setPlayerPlaybackState(QMediaPlayer::State playerPlaybackState)
+void ManageAudioPlayer::setPlayerPlaybackState(QMediaPlayer::PlaybackState playerPlaybackState)
 {
     if (mPlayerPlaybackState == playerPlaybackState) {
         return;
@@ -258,6 +263,9 @@ void ManageAudioPlayer::setPlayerPlaybackState(QMediaPlayer::State playerPlaybac
     if (!mSkippingCurrentTrack) {
         switch(mPlayerPlaybackState) {
         case QMediaPlayer::StoppedState:
+            if (mPlayerStatus == QMediaPlayer::EndOfMedia) {
+                Q_EMIT finishedPlayingTrack(mCurrentTrack.data(mUrlRole).toUrl(), QDateTime::currentDateTime());
+            }
             if (mPlayerStatus == QMediaPlayer::EndOfMedia || mPlayerStatus == QMediaPlayer::InvalidMedia) {
                 triggerSkipNextTrack();
             }
@@ -370,7 +378,6 @@ void ManageAudioPlayer::playPause()
     case QMediaPlayer::NoMedia:
     case QMediaPlayer::StalledMedia:
     case QMediaPlayer::InvalidMedia:
-    case QMediaPlayer::UnknownMediaStatus:
         break;
     }
 }
@@ -416,6 +423,7 @@ void ManageAudioPlayer::setCurrentPlayingForRadios(const QString &title, const Q
 
 void ManageAudioPlayer::setPlayControlPosition(int playerPosition)
 {
+    qCDebug(orgKdeElisaPlayer()) << "ManageAudioPlayer::setPlayControlPosition" << playerPosition;
     Q_EMIT seek(playerPosition);
 }
 
@@ -436,6 +444,7 @@ void ManageAudioPlayer::setPersistentState(const QVariantMap &persistentStateVal
 
 void ManageAudioPlayer::playerSeek(int position)
 {
+    qCDebug(orgKdeElisaPlayer()) << "ManageAudioPlayer::playerSeek" << position;
     Q_EMIT seek(position);
 }
 
